<?php
/**
 * Offers helper functions for frontend
 */
class d2u_machinery_frontend_helper {
	/**
	 * Returns breadcrumbs. Not from article path, but only part from this addon.
	 * @return string[] Breadcrumb elements
	 */
	public static function getBreadcrumbs() {
		$breadcrumbs = [];

		// Prepare objects first for sorting in correct order
		$category = FALSE;
		$machine = FALSE;
		$used_machine = FALSE;
		$url_data = [];
		if(rex_addon::get("url")->isAvailable()) {
			$url_data = UrlGenerator::getData();
		}
		if(filter_input(INPUT_GET, 'machine_id', FILTER_VALIDATE_INT, ['options' => ['default'=> 0]]) > 0 || (rex_addon::get("url")->isAvailable() && isset($url_data->urlParamKey) && $url_data->urlParamKey === "machine_id")) {
			$machine_id = filter_input(INPUT_GET, 'machine_id', FILTER_VALIDATE_INT);
			if(rex_addon::get("url")->isAvailable() && UrlGenerator::getId() > 0) {
				$machine_id = UrlGenerator::getId();
			}
			$machine = new Machine($machine_id, rex_clang::getCurrentId());
			$category = $machine->category;
		}
		if(filter_input(INPUT_GET, 'category_id', FILTER_VALIDATE_INT, ['options' => ['default'=> 0]]) > 0 || (rex_addon::get("url")->isAvailable() && $urlParamKey === "category_id")
				|| filter_input(INPUT_GET, 'used_rent_category_id', FILTER_VALIDATE_INT, ['options' => ['default'=> 0]]) > 0 || (rex_addon::get("url")->isAvailable() && $urlParamKey === "used_rent_category_id")
				|| filter_input(INPUT_GET, 'used_sale_category_id', FILTER_VALIDATE_INT, ['options' => ['default'=> 0]]) > 0 || (rex_addon::get("url")->isAvailable() && $urlParamKey === "used_sale_category_id")) {
			// Category for normal machines
			$category_id = filter_input(INPUT_GET, 'category_id', FILTER_VALIDATE_INT);
			if(rex_plugin::get("d2u_machinery", "used_machines")->isAvailable() && filter_input(INPUT_GET, 'used_rent_category_id', FILTER_VALIDATE_INT, ['options' => ['default'=> 0]]) > 0) {
				// Category for used machines (rent)
				$category_id = filter_input(INPUT_GET, 'used_rent_category_id', FILTER_VALIDATE_INT);
			}
			elseif(rex_plugin::get("d2u_machinery", "used_machines")->isAvailable() && filter_input(INPUT_GET, 'used_sale_category_id', FILTER_VALIDATE_INT, ['options' => ['default'=> 0]]) > 0) {
				// Category for used machines (sale)
				$category_id = filter_input(INPUT_GET, 'used_sale_category_id', FILTER_VALIDATE_INT);
			}
			if(rex_addon::get("url")->isAvailable() && UrlGenerator::getId() > 0) {
				$category_id = UrlGenerator::getId();
			}
			$category = new Category($category_id, rex_clang::getCurrentId());
		}
		if(filter_input(INPUT_GET, 'used_rent_machine_id', FILTER_VALIDATE_INT, ['options' => ['default'=> 0]]) > 0 || filter_input(INPUT_GET, 'used_sale_machine_id', FILTER_VALIDATE_INT, ['options' => ['default'=> 0]]) > 0 || (rex_addon::get("url")->isAvailable() && isset($url_data->urlParamKey) && ($url_data->urlParamKey === "used_rent_machine_id" || $url_data->urlParamKey === "used_sale_machine_id"))) {
			$used_machine_id = filter_input(INPUT_GET, 'used_rent_machine_id', FILTER_VALIDATE_INT, ['options' => ['default'=> 0]]) > 0 ? filter_input(INPUT_GET, 'used_rent_machine_id', FILTER_VALIDATE_INT) : filter_input(INPUT_GET, 'used_sale_machine_id', FILTER_VALIDATE_INT);
			if(rex_addon::get("url")->isAvailable() && UrlGenerator::getId() > 0) {
				$used_machine_id = UrlGenerator::getId();
			}
			$used_machine = new UsedMachine($used_machine_id, rex_clang::getCurrentId());
			$category = $used_machine->category;
		}

		// Breadcrumbs
		if($category !== FALSE) {
			if($category->parent_category !== FALSE) {
				$breadcrumbs[] = '<a href="' . $category->parent_category->getUrl() . '">' . $category->parent_category->name . '</a>';
			}
			$breadcrumbs[] = '<a href="' . $category->getUrl() . '">' . $category->name . '</a>';
			// Cutting range configurator
			if(rex_plugin::get("d2u_machinery", "machine_steel_processing_extension")->isAvailable() && filter_input(INPUT_GET, 'cutting_range_configurator') != "") {
				$breadcrumbs[] = '<a href="' . $category->getURLCuttingRangeConfigurator() . '">' . $category->steel_processing_saw_cutting_range_title . '</a>';
			}
		}
		if($machine !== FALSE) {
			$breadcrumbs[] = '<a href="' . $machine->getUrl() . '">' . ($machine->lang_name == "" ? $machine->name : $machine->lang_name) . '</a>';
		}
		if($used_machine !== FALSE) {
			$breadcrumbs[] = '<a href="' . $used_machine->getUrl() . '">' . $used_machine->manufacturer ." ". $used_machine->name . '</a>';
		}
		
		// Industry sectors
		if(rex_plugin::get("d2u_machinery", "industry_sectors")->isAvailable() && (filter_input(INPUT_GET, 'industry_sector_id', FILTER_VALIDATE_INT, ['options' => ['default'=> 0]]) > 0 || (rex_addon::get("url")->isAvailable() && isset($url_data->urlParamKey) && $url_data->urlParamKey === "industry_sector_id"))) {
			$industry_sector_id = filter_input(INPUT_GET, 'industry_sector_id', FILTER_VALIDATE_INT);
			if(rex_addon::get("url")->isAvailable() && UrlGenerator::getId() > 0) {
				$industry_sector_id = UrlGenerator::getId();
			}
			$industry_sector = new IndustrySector($industry_sector_id, rex_clang::getCurrentId());
			$breadcrumbs[] = '<a href="' . $industry_sector->getUrl() . '">' . $industry_sector->name . '</a>';
		}
		
		return $breadcrumbs;
	}
}